/*////////////////////////////////////////////////////////////////

RETRIEVE ALL LANGUAGE VALUES FOR A TOKEN

Author: 	Bob Carver
Created:	29 Jun 2010

Return a result set of all defined language values for a
given language token, with the languages associated with
each such value returned in the language called for by
the provided language token.

////////////////////////////////////////////////////////////////*/

DROP PROCEDURE IF EXISTS LNGV_ListByLanguages;

CREATE PROCEDURE LNGV_ListByLanguages
(
	IN parmToken			varchar(50),
	IN parmLanguageToken	varchar(50)
)
BEGIN

		SELECT B.LNGV_Text As Language, A.LNGV_Text AS Translation FROM
		(
            # first get the token's values by language token
			SELECT LNGV_Text, LNGN_NameToken, LNGT_Token
            FROM Language_Values
            LEFT JOIN Language_Tokens 		ON LNGV_LNGT_ID = LNGT_ID
            LEFT JOIN Language_Collections	ON LNGT_LNGC_ID = LNGC_ID
            LEFT JOIN Language_Sets		ON LNGV_LNGS_ID = LNGS_ID
            LEFT JOIN Language_Names		ON LNGS_LNGN_ID = LNGN_ID
            WHERE LNGT_Token = 	parmToken
		) AS A
		LEFT JOIN
		(
            # this , along with the ON and WHERE clauses, will allow
			# us to then resolve the language tokens themselves
			SELECT LNGN_NameToken, LNGT_Token, LNGV_Text
			FROM Language_Values
            LEFT JOIN Language_Tokens 		ON LNGV_LNGT_ID = LNGT_ID
            LEFT JOIN Language_Collections	ON LNGT_LNGC_ID = LNGC_ID
            LEFT JOIN Language_Sets 		ON LNGV_LNGS_ID = LNGS_ID
            LEFT JOIN Language_Names 		ON LNGS_LNGN_ID = LNGN_ID
            WHERE UPPER(LNGC_Name) = 'COMMON'
		) AS B
		ON B.LNGT_Token = A.LNGN_NameToken
		WHERE B.LNGN_NameToken = parmLanguageToken;

 END;
