
DROP PROCEDURE IF EXISTS NATN_GetPricing;

/*//////////////////////////////////////////////////////////////////

	RETRIEVE COUNTRY-SPECIFIC PRICING

	DEFAULT PRICING WILL ALWAYS BE IN FIRST ROW (OPRS_ID = NULL)

	parmGetType options:
		'S' system-wide settings only
		'O' operator-specific settings (+ system-wide settings)
		'A' all operator-specific settings (+ system-wide seettings)

//////////////////////////////////////////////////////////////////*/

CREATE PROCEDURE NATN_GetPricing
(
	IN parmGetType		char(1),				# always required
	IN parmUSROID		mediumint UNSIGNED,		# USRO_ID for active user
	IN parmNATNID		smallint UNSIGNED,		# NATN_ID for country in question
	IN parmOPRSID		mediumint UNSIGNED		# OPRS_ID for operator (GetType=O, ignored otherwise)
)
BEGIN

	# first we need to get user's Timezone name
	DECLARE usertz varchar(30);
	SELECT USRM_TimeZone INTO usertz FROM Users_Main JOIN Users_Operators ON USRO_USRM_ID = USRM_ID WHERE USRO_ID = parmUSROID;

	# retrieve system-wide defaults only
	IF UPPER(parmGetType) = 'S' THEN

		BEGIN

			SELECT NATN_ID,
					NULL AS OPRS_ID,
					NULL AS OPRS_Name,
					IFNULL(NATO_DefaultLandingFee		, 0 ) AS DefaultLandingFee,
					IFNULL(NATO_DefaultHotelRate		, 0 ) AS DefaultHotelRate,
					IFNULL(NATO_DefaultGroundXprtRate	, 0 ) AS DefaultGroundXprtRate,
					IFNULL(NATO_IncludeEuroControl		, 0 ) AS IncludeEuroControl,
					IFNULL(NATO_ExcludeFromQuotes		, 0 ) AS ExcludeFromQuotes,
					IFNULL(NATO_ExclusionReason			, '') AS ExclusionReason
			FROM Countries_Main
			LEFT OUTER JOIN Countries_Operators ON NATO_NATN_ID = NATN_ID AND NATO_OPRS_ID IS NULL
			WHERE 	NATN_ID = parmNATNID;

		END;

	# retrieve a single operator's country-specific pricing (+ system-wide defaults)
	ELSEIF UPPER(parmGetType) = 'O' THEN

		BEGIN

			SELECT NATN_ID,
					NULL AS OPRS_ID,
					NULL AS OPRS_Name,
					IFNULL(NATO_DefaultLandingFee		, 0 ) AS DefaultLandingFee,
					IFNULL(NATO_DefaultHotelRate		, 0 ) AS DefaultHotelRate,
					IFNULL(NATO_DefaultGroundXprtRate	, 0 ) AS DefaultGroundXprtRate,
					IFNULL(NATO_IncludeEuroControl		, 0 ) AS IncludeEuroControl,
					IFNULL(NATO_ExcludeFromQuotes		, 0 ) AS ExcludeFromQuotes,
					IFNULL(NATO_ExclusionReason			, '') AS ExclusionReason
			FROM Countries_Main
			LEFT OUTER JOIN Countries_Operators ON NATO_NATN_ID = NATN_ID AND NATO_OPRS_ID IS NULL

			WHERE 	NATN_ID = parmNATNID

			UNION

			SELECT	IFNULL(NATN_ID,parmNATNID),
					OPRS_ID,
					ELT(1+FIELD('0',CAST(LENGTH(IFNULL(OPRS_ShortName,'')) AS CHAR),CAST(LENGTH(OPRS_LegalName) AS CHAR)),OPRS_ShortName,OPRS_LegalName) AS OPRS_Name,
					IFNULL(NATO_DefaultLandingFee		, -1) AS DefaultLandingFee,
					IFNULL(NATO_DefaultHotelRate		, -1) AS DefaultHotelRate,
					IFNULL(NATO_DefaultGroundXprtRate	, -1) AS DefaultGroundXprtRate,
					IFNULL(NATO_IncludeEuroControl		, -1) AS IncludeEuroControl,
					IFNULL(NATO_ExcludeFromQuotes		, -1) AS ExcludeFromQuotes,
					IFNULL(NATO_ExclusionReason			, '') AS ExclusionReason
			FROM Operators
			LEFT OUTER JOIN Countries_Operators	ON NATO_OPRS_ID = OPRS_ID AND NATO_NATN_ID = parmNATNID
			LEFT OUTER JOIN Countries_Main			ON NATO_NATN_ID = NATN_ID

			WHERE OPRS_ID = parmOPRSID

			ORDER BY OPRS_ID;

		END;

	# retrieve all operators' country-specific pricing (+ system-wide defaults)
	ELSE

		BEGIN

			SELECT NATN_ID,
					NULL AS OPRS_ID,
					NULL AS OPRS_Name,
					IFNULL(NATO_DefaultLandingFee		, 0 ) AS DefaultLandingFee,
					IFNULL(NATO_DefaultHotelRate		, 0 ) AS DefaultHotelRate,
					IFNULL(NATO_DefaultGroundXprtRate	, 0 ) AS DefaultGroundXprtRate,
					IFNULL(NATO_IncludeEuroControl		, 0 ) AS IncludeEuroControl,
					IFNULL(NATO_ExcludeFromQuotes		, 0 ) AS ExcludeFromQuotes,
					IFNULL(NATO_ExclusionReason			, '') AS ExclusionReason
			FROM Countries_Main
			LEFT OUTER JOIN Countries_Operators ON NATO_NATN_ID = NATN_ID AND NATO_OPRS_ID IS NULL

			WHERE 	NATN_ID = parmNATNID

			UNION

			SELECT	IFNULL(NATN_ID,parmNATNID),
					OPRS_ID,
					ELT(1+FIELD('0',CAST(LENGTH(IFNULL(OPRS_ShortName,'')) AS CHAR),CAST(LENGTH(OPRS_LegalName) AS CHAR)),OPRS_ShortName,OPRS_LegalName) AS OPRS_Name,
					IFNULL(NATO_DefaultLandingFee		, -1) AS DefaultLandingFee,
					IFNULL(NATO_DefaultHotelRate		, -1) AS DefaultHotelRate,
					IFNULL(NATO_DefaultGroundXprtRate	, -1) AS DefaultGroundXprtRate,
					IFNULL(NATO_IncludeEuroControl		, -1) AS IncludeEuroControl,
					IFNULL(NATO_ExcludeFromQuotes		, -1) AS ExcludeFromQuotes,
					IFNULL(NATO_ExclusionReason			, '') AS ExclusionReason
			FROM Operators
			LEFT OUTER JOIN Countries_Operators	ON NATO_OPRS_ID = OPRS_ID AND NATO_NATN_ID = parmNATNID
			LEFT OUTER JOIN Countries_Main 		ON NATO_NATN_ID = NATN_ID

			ORDER BY OPRS_ID, OPRS_Name;

		END;

	END IF;

END;