/*////////////////////////////////////////////////////////////////

INSERT/UPDATE Operators Table

Author: 	Bob Carver
Created:	09 Jul 2010

Controls:
1. If parmId is negative, then INSERT is done; else UPDATE

////////////////////////////////////////////////////////////////*/

DROP PROCEDURE IF EXISTS OPRS_Update;

CREATE PROCEDURE OPRS_Update
(
    IN parmID					smallint	UNSIGNED,
	IN parmParentID				mediumint	UNSIGNED,
	IN parmIsDivision			boolean,
	IN parmIsInactive			boolean,
	IN parmLegalName			varchar(100),
	IN parmShortName			varchar(100),
	IN parmAddressLine1			varchar(50),
	IN parmAddressLine2			varchar(50),
	IN parmAddressLine3			varchar(50),
	IN parmCity					varchar(100),
	IN parmStateID				mediumint	UNSIGNED,
	IN parmZip					varchar(10),
	IN parmNATNID				smallint	UNSIGNED,
	IN parmTimezone				varchar(30),
	IN parmContactNameFirst		varchar(35),
	IN parmContactNameMiddle	varchar(25),
	IN parmContactNameLast		varchar(35),
	IN parmContactNameSuffix	varchar(15),
	IN parmContactNickName		varchar(25),
	IN parmContactAddressLine1 	varchar(50),
	IN parmContactAddressLine2 	varchar(50),
	IN parmContactAddressLine3 	varchar(50),
	IN parmContactCity 			varchar(100),
	IN parmContactStateID 		mediumint	UNSIGNED,
	IN parmContactZip 			varchar(10),
	IN parmContactCountryID 	smallint	UNSIGNED,
	IN parmContactTimezone		varchar(30),
	IN parmEmailPrimary			varchar(100),
    IN parmEmailAlternate		varchar(100),
    IN parmUpdateUser			varchar(25),
    IN parmUpdateUserIP1		varchar(64),
    IN parmUpdateUserIP2		varchar(64)
)
	BEGIN
		IF parmID = 0 THEN
		# insert new operator
			DoInsert: BEGIN
				INSERT INTO Operators
				(
					OPRS_ParentID,
					OPRS_IsDivision,
					OPRS_IsInactive,
					OPRS_LegalName,
					OPRS_ShortName,
					OPRS_AddressLine1,
					OPRS_AddressLine2,
					OPRS_AddressLine3,
					OPRS_City,
					OPRS_StateID,
					OPRS_Zip,
					OPRS_CountryID,
					OPRS_TimeZone,
					OPRS_ContactNameFirst,
					OPRS_ContactNameMiddle,
					OPRS_ContactNameLast,
					OPRS_ContactNameSuffix,
					OPRS_ContactNickName,
					OPRS_ContactAddressLine1,
					OPRS_ContactAddressLine2,
					OPRS_ContactAddressLine3,
					OPRS_ContactCity,
					OPRS_ContactStateID,
					OPRS_ContactZip,
					OPRS_ContactCountryID,
					OPRS_ContactTimeZone,
					OPRS_EmailPrimary,
					OPRS_EmailAlternate,
					OPRS_UpdateUser,
					OPRS_UpdateUserIP1,
					OPRS_UpdateUserIP2,
					OPRS_UpdateTimestamp
				)
				VALUES
				(
					parmParentID,
					parmIsDivision,
					parmIsInactive,
					parmLegalName,
					parmShortName,
					parmAddressLine1,
					parmAddressLine2,
					parmAddressLine3,
					parmCity,
					parmStateID,
					parmZip,
					parmNATNID,
					parmTimezone,
					parmContactNameFirst,
					parmContactNameMiddle,
					parmContactNameLast,
					parmContactNameSuffix,
					parmContactNickName,
					parmContactAddressLine1,
					parmContactAddressLine2,
					parmContactAddressLine3,
					parmContactCity,
					parmContactStateID,
					parmContactZip,
					parmContactCountryID,
					parmContactTimezone,
					parmEmailPrimary,
					parmEmailAlternate,
					parmUpdateUser,
					NULLIF(CONV(parmUpdateUserIP1,2,10),0),
					CONV(parmUpdateUserIP2,2,10),
					UTC_TIMESTAMP()
				);
				SELECT LAST_INSERT_ID();
			END DoInsert;
		ELSE
		# update existing operator
			DoUpdate: BEGIN
				UPDATE Operators SET
					OPRS_ParentID			= parmParentID,
					OPRS_IsDivision			= parmIsDivision,
					OPRS_IsInactive			= parmIsInactive,
					OPRS_LegalName			= parmLegalName,
					OPRS_ShortName			= parmShortName,
					OPRS_AddressLine1		= parmAddressLine1,
					OPRS_AddressLine2		= parmAddressLine2,
					OPRS_AddressLine3		= parmAddressLine3,
					OPRS_City				= parmCity,
					OPRS_StateID			= parmStateID,
					OPRS_Zip				= parmZip,
					OPRS_CountryID			= parmNATNID,
					OPRS_TimeZone			= parmTimezone,
					OPRS_ContactNameFirst	= parmContactNameFirst,
					OPRS_ContactNameMiddle	= parmContactNameMiddle,
					OPRS_ContactNameLast	= parmContactNameLast,
					OPRS_ContactNameSuffix	= parmContactNameSuffix,
					OPRS_ContactNickName	= parmContactNickName,
					OPRS_ContactAddressLine1= parmContactAddressLine1,
					OPRS_ContactAddressLine2= parmContactAddressLine2,
					OPRS_ContactAddressLine3= parmContactAddressLine3,
					OPRS_ContactCity		= parmContactCity,
					OPRS_ContactStateID		= parmContactStateID,
					OPRS_ContactZip			= parmContactZip,
					OPRS_ContactCountryID	= parmContactCountryID,
					OPRS_ContactTimeZone	= parmContactTimezone,
					OPRS_EmailPrimary		= parmEmailPrimary,
					OPRS_EmailAlternate		= parmEmailAlternate,
					OPRS_UpdateUser			= parmUpdateUser,
					OPRS_UpdateUserIP1		= NULLIF(CONV(parmUpdateUserIP1,2,10),0),
					OPRS_UpdateUserIP2		= CONV(parmUpdateUserIP2,2,10),
					OPRS_UpdateTimestamp 	= UTC_TIMESTAMP()
				WHERE OPRS_ID				= parmID;
				SELECT parmID;
			END DoUpdate;
		END IF;
	END;
