/*////////////////////////////////////////////////////////////////

RETRIEVE ACTIVE USER PRIVILEGES

Author: 	Bob Carver
Created:	24 Feb 2010

Controls:
1. parmKey 		USRM_ID for user in play
2. parmFavLit	the language-specific value for the FAVORITES
				category

Modifications

02 Mar 2010	Added code to filter returned recordset according to
			whether or not the user is allowed to "see" PRVN's
			that are restricted only to super users

02 Mar 2010	Added code to ensure settings were selected that apply
			to a specific operator via parmOPRSKey

08 Mar 2010	Made sure Favorites were sequenced according to
			PRVS_FavoriteSeq

20 Mar 2010	Ensured all privilege settings returned True for admins

17 Jul 2010 Made sure non-menu PRVN's aren't included

////////////////////////////////////////////////////////////////*/

DROP PROCEDURE IF EXISTS PRVS_GetPrivileges;

CREATE PROCEDURE PRVS_GetPrivileges
(
	parmUSRMKey mediumint	UNSIGNED,
	parmOPRSKey	mediumint	UNSIGNED,
	parmFavLit	varchar(50)
)

BEGIN

		SELECT	PRVG_ID,
                PRVG_Sequence + 1 AS PRVG_Sequence,
                PRVG_Token,
                PRVN_ID,
                PRVN_Sequence + 1 AS PRVN_Sequence,
                PRVN_Token,
                PRVS_CategorySeq,
                PRVN_Program,
                PRVN_IncludeInMenu,
                PRVN_Pseudo,
                PRVS_Add | USRM_IsSuperUser | USRO_IsAdministrator AS PRVS_Add,
                PRVS_Edit,
                PRVS_Print,
                PRVS_PrintList,
                PRVS_Export,
                PRVS_Inactivate,
                PRVS_Delete,
                PRVS_Notes,
                PRVS_ItemsPerPage,
                PRVS_DropDownLimit

    	FROM	Privilege_Groups
    			LEFT JOIN Privilege_Names		ON PRVN_PRVG_ID = PRVG_ID
    			LEFT JOIN Privilege_Settings	ON PRVS_PRVN_ID = PRVN_ID
    			LEFT JOIN Users_Operators		ON PRVS_USRO_ID = USRO_ID
    			LEFT JOIN Users_Main			ON USRO_USRM_ID = USRM_ID

    	WHERE 	IFNULL(-1,USRO_OPRS_ID)	= IFNULL(-1,parmOPRSKey)
		AND		PRVN_IncludeInMenu 		= 1
    	AND		USRO_USRM_ID 			= parmUSRMKey
		AND
		(
				(USRM_IsSuperUser       = 1)
			OR	(PRVN_SuperUserOnly 	= 0 AND USRO_IsAdministrator = 1)
			OR
			(
				(PRVN_SuperUserOnly 	= 0 AND USRO_IsAdministrator = 0)
				AND
				(
        			PRVS_View			= 1
        			OR
        			PRVS_Add			= 1
        			OR
        			PRVS_Edit			= 1
        			OR
        			PRVS_Print			= 1
        			OR
        			PRVS_PrintList		= 1
        			OR
        			PRVS_Export			= 1
        			OR
        			PRVS_Inactivate		= 1
        			OR
        			PRVS_Delete			= 1
        			OR
        			PRVS_Notes			= 1
    			)
			)
		)

    	UNION

        SELECT	0						AS PRVG_ID,
                0						AS PRVG_Sequence,
                parmFavLit 				AS PRVG_Token,
                PRVN_ID,
                0 						AS PRVN_Sequence,
                PRVN_Token,
                PRVS_FavoriteSeq		AS PRVS_CategorySeq,
                PRVN_Program,
                1						AS PRVN_IncludeInMenu,
                PRVN_Pseudo,
                PRVS_Add,
                PRVS_Edit,
                PRVS_Print,
                PRVS_PrintList,
                PRVS_Export,
                PRVS_Inactivate,
                PRVS_Delete,
                PRVS_Notes,
                PRVS_ItemsPerPage,
                PRVS_DropDownLimit

    	FROM	Privilege_Groups
    			LEFT JOIN Privilege_Names		ON PRVN_PRVG_ID = PRVG_ID
    			LEFT JOIN Privilege_Settings	ON PRVS_PRVN_ID = PRVN_ID
    			LEFT JOIN Users_Operators		ON PRVS_USRO_ID = USRO_ID
    			LEFT JOIN Users_Main			ON USRO_USRM_ID = USRM_ID

    	WHERE 	IFNULL(-1,USRO_OPRS_ID)	= IFNULL(-1,parmOPRSKey)
		AND		PRVN_IncludeInMenu 		= 1
    	AND		USRO_USRM_ID 			= parmUSRMKey
    	AND		PRVS_FavoriteSeq		> 0
		AND
		(
				(USRM_IsSuperUser       = 1)
			OR	(PRVN_SuperUserOnly 	= 0 AND USRO_IsAdministrator = 1)
			OR
			(
				(PRVN_SuperUserOnly 	= 0 AND USRO_IsAdministrator = 0)
				AND
				(
        			PRVS_View			= 1
        			OR
        			PRVS_Add			= 1
        			OR
        			PRVS_Edit			= 1
        			OR
        			PRVS_Print			= 1
        			OR
        			PRVS_PrintList		= 1
        			OR
        			PRVS_Export			= 1
        			OR
        			PRVS_Inactivate		= 1
        			OR
        			PRVS_Delete			= 1
        			OR
        			PRVS_Notes			= 1
    			)
			)
		)

		ORDER BY	PRVG_Sequence,
    				PRVS_CategorySeq,
					PRVN_Sequence,
    				PRVG_Token;

END;