/*////////////////////////////////////////////////////////////////

SET ACCESS PRIVILEGES FOR ADMIN USER (OR SUPERUSER)

Author: 	Bob Carver
Created:	09 Jul 2010

Defines all possible access permissions for an admin user

Controls:
1. parmUSOKey 			USRO_ID for the user in play
2. parmAdminType		A for Operator Admins, S for SuperUsers
3. parmUpdateUserIP1	IP address part 1
4. parmUpdateUserIP2	IP address part 2

////////////////////////////////////////////////////////////////*/

DROP PROCEDURE IF EXISTS PRVS_SetForAdmin;

CREATE PROCEDURE PRVS_SetForAdmin
(
	parmUSROKey		mediumint	UNSIGNED,
	parmAdminType	char(1),
	parmUserIP1		varchar(64),
	parmUserIP2		varchar(64)
)

BEGIN

	DECLARE SU boolean DEFAULT 0;
	IF parmAdminType = 'S' THEN SET SU = 1; END IF;

	START TRANSACTION;

	# throw away the current settings for the user, for the operator
	DELETE FROM Privilege_Settings WHERE PRVS_USRO_ID = parmUSROKey;

	# now put in the new ones
	INSERT INTO Privilege_Settings
	(
		PRVS_PRVN_ID,
		PRVS_USRO_ID,
		PRVS_View,
		PRVS_Add,
		PRVS_Edit,
		PRVS_Print,
		PRVS_PrintList,
		PRVS_Export,
		PRVS_Inactivate,
		PRVS_Delete,
		PRVS_Notes,
		PRVS_ItemsPerPage,
		PRVS_DropDownLimit,
		PRVS_UpdateUser,
		PRVS_UpdateUserIP1,
		PRVS_UpdateUserIP2,
		PRVS_UpdateTimestamp
	)
	SELECT	PRVN_ID,
			parmUSROKey,
			PRVN_Pseudo,
			PRVN_Add,
			PRVN_Edit,
			PRVN_Print,
			PRVN_PrintList,
			PRVN_Export,
			PRVN_Inactivate,
			PRVN_Delete,
			PRVN_Notes,
			PRVN_ItemsPerPage,
			PRVN_DropDownLimit,
			(SELECT USRM_Name FROM Users_Main JOIN Users_operators ON USRM_ID = USRO_USRM_ID WHERE USRO_ID = parmUSROKey),
			NULLIF(CONV(parmUserIP1,2,10),0),
			CONV(parmUserIP2,2,10),
			UTC_TIMESTAMP()
	FROM 	Privilege_Names

	WHERE 	(PRVN_SuperUserOnly = 0 OR PRVN_SuperUserOnly = SU)
	AND		PRVN_IncludeInMenu = 1
	AND
	(
		PRVN_Pseudo		= 1
		OR
		PRVN_Add		= 1
		OR
		PRVN_Edit		= 1
		OR
		PRVN_Print		= 1
		OR
		PRVN_PrintList	= 1
		OR
		PRVN_Export		= 1
		OR
		PRVN_Inactivate	= 1
		OR
		PRVN_Delete		= 1
		OR
		PRVN_Notes		= 1
	);

	# special handling for PRVN_Changes
	INSERT INTO Privilege_Settings
	(
		PRVS_PRVN_ID,
		PRVS_USRO_ID,
		PRVS_View,
		PRVS_Add,
		PRVS_Edit,
		PRVS_Print,
		PRVS_PrintList,
		PRVS_Export,
		PRVS_Inactivate,
		PRVS_Delete,
		PRVS_Notes,
		PRVS_ItemsPerPage,
		PRVS_DropDownLimit,
		PRVS_UpdateUser,
		PRVS_UpdateUserIP1,
		PRVS_UpdateUserIP2,
		PRVS_UpdateTimestamp
	)
	SELECT	PRVN_ID,
			parmUSROKey,
			1,				# view ........ yes for all
			SU,				# add ......... superusers yes, admins no
			SU,				# edit ........ superusers yes, admins no
			0,				# print	....... N/A
			0,				# print list ..	N/A
			0,				# export ...... N/A
			0,				# inactivate .. N/A
			SU,				# delete ...... superusers yes, admins no
			0,				# notes ....... N/A
			PRVN_ItemsPerPage,
			PRVN_DropDownLimit,
			(SELECT USRM_Name FROM Users_Main JOIN Users_operators ON USRM_ID = USRO_USRM_ID WHERE USRO_ID = parmUSROKey),
			NULLIF(CONV(parmUserIP1,2,10),0),
			CONV(parmUserIP2,2,10),
			UTC_TIMESTAMP()
	FROM 	Privilege_Names

	WHERE 	PRVN_Token = 'PRVN_Changes';

	# special handling for PRVN_UserChanges
	INSERT INTO Privilege_Settings
	(
		PRVS_PRVN_ID,
		PRVS_USRO_ID,
		PRVS_View,
		PRVS_Add,
		PRVS_Edit,
		PRVS_Print,
		PRVS_PrintList,
		PRVS_Export,
		PRVS_Inactivate,
		PRVS_Delete,
		PRVS_Notes,
		PRVS_ItemsPerPage,
		PRVS_DropDownLimit,
		PRVS_UpdateUser,
		PRVS_UpdateUserIP1,
		PRVS_UpdateUserIP2,
		PRVS_UpdateTimestamp
	)
	SELECT	PRVN_ID,
			parmUSROKey,
			1,				# view ........ yes for all
			0,				# add ......... no for all
			1,				# edit ........ yes for all
			0,				# print	....... N/A
			0,				# print list ..	N/A
			0,				# export ...... N/A
			0,				# inactivate .. N/A
			0,				# delete ...... N/A
			0,				# notes ....... N/A
			PRVN_ItemsPerPage,
			PRVN_DropDownLimit,
			(SELECT USRM_Name FROM Users_Main JOIN Users_operators ON USRM_ID = USRO_USRM_ID WHERE USRO_ID = parmUSROKey),
			NULLIF(CONV(parmUserIP1,2,10),0),
			CONV(parmUserIP2,2,10),
			UTC_TIMESTAMP()
	FROM 	Privilege_Names

	WHERE 	PRVN_Token = 'PRVN_UserOptions';

	# special handling for PRVN_RefValues
	INSERT INTO Privilege_Settings
	(
		PRVS_PRVN_ID,
		PRVS_USRO_ID,
		PRVS_View,
		PRVS_Add,
		PRVS_Edit,
		PRVS_Print,
		PRVS_PrintList,
		PRVS_Export,
		PRVS_Inactivate,
		PRVS_Delete,
		PRVS_Notes,
		PRVS_ItemsPerPage,
		PRVS_DropDownLimit,
		PRVS_UpdateUser,
		PRVS_UpdateUserIP1,
		PRVS_UpdateUserIP2,
		PRVS_UpdateTimestamp
	)
	SELECT	PRVN_ID,
			parmUSROKey,
			1,				# view ........ yes for all
			PRVN_Add,		# add ......... as per PRVN
			PRVN_Edit,		# edit ........ as per PRVN
			PRVN_Print,		# print	....... as per PRVN
			PRVN_PrintList, # print list ..	as per PRVN
			PRVN_Export,	# export ...... as per PRVN
			PRVN_Inactivate,# inactivate .. as per PRVN
			PRVN_Delete,	# delete ...... as per PRVN
			PRVN_Notes,		# notes ....... as per PRVN
			PRVN_ItemsPerPage,
			PRVN_DropDownLimit,
			(SELECT USRM_Name FROM Users_Main JOIN Users_operators ON USRM_ID = USRO_USRM_ID WHERE USRO_ID = parmUSROKey),
			NULLIF(CONV(parmUserIP1,2,10),0),
			CONV(parmUserIP2,2,10),
			UTC_TIMESTAMP()
	FROM 	Privilege_Names

	WHERE 	PRVN_Token = 'PRVN_RefValues';

	COMMIT;

END;