/*////////////////////////////////////////////////////////////////

RESEQUENCE A USER'S MENU ORDER (or REMOVE A FAVORITE)

Author: 	Bob Carver
Created:	7 Mar 2010

Controls:
1. parmAction	REMOVEFAV or RESEQUENCE
2. parmUSRMKey 	USRM_ID for user in play
3. parmOPRSKey	OPRS_ID for operator in play (may be NULL)
4. parmPRVNKey	PRVN_ID for privlege name (function)
5. parmPRVGKey	(RESEQUENCE only) PRVG_ID of group
6. parmNewSeq	(RESEQUENCE only) (PRVN_ID,Seq|PRVN_ID,Seq, ...|)

////////////////////////////////////////////////////////////////*/

DROP PROCEDURE IF EXISTS PRVS_UpdateMenu;

CREATE PROCEDURE PRVS_UpdateMenu
(
	parmAction			varchar(25),
	parmUSRMKey			mediumint	UNSIGNED,
	parmOPRSKey			mediumint	UNSIGNED,
	parmPRVNKey			smallint	UNSIGNED,
	parmPRVGKey			tinyint		UNSIGNED,
	parmSeqString		varchar(1000),
	parmUpdateUserIP1	varchar(64),
	parmUpdateUserIP2	varchar(64)
)

BEGIN

    DECLARE	workSeq	varchar(1000);
    DECLARE	slice	varchar(10);
    DECLARE	prvn	smallint;
    DECLARE	seq		smallint;

	-- REMOVE A FAVORITE
	-- set FavoriteSeq to 0 (which will prevent it's being selected via PRVS_GetPrivileges)
	-- and update UpdateUser, UpdateUserIP1, UpdateUserIP2 to keep track of who last changed the PRVS instance
	IF UPPER(parmAction) = 'REMOVEFAV' THEN

			UPDATE Privilege_Settings SET
				PRVS_FavoriteSeq 	= 0,
            	PRVS_UpdateUser		= (SELECT USRM_Name FROM Users_Main WHERE USRM_ID = parmUSRMKey),
            	PRVS_UpdateUserIP1	= NULLIF(CONV(parmUpdateUserIP1,2,10),0),
            	PRVS_UpdateUserIP2	= CONV(parmUpdateUserIP2,2,10),
				PRVS_UpdateTimestamp= UTC_TIMESTAMP()
			WHERE PRVS_ID =
			(
				SELECT	PRVS_ID
				FROM	(	SELECT * FROM Privilege_Settings
							INNER JOIN Users_Operators ON USRO_ID = PRVS_USRO_ID
						) AS t1
						WHERE	t1.PRVS_PRVN_ID	 =  parmPRVNKey
						AND		t1.USRO_USRM_ID	 =  parmUSRMKey
						AND		t1.USRO_OPRS_ID	<=> parmOPRSKey
			);

	END IF;

	-- RESEQUENCE CATGEORY/GROUP FUNCTIONS
	IF UPPER(parmAction) = 'RESEQUENCE' THEN
		BEGIN

			-- IF FAVORITES CATEGORY...
			IF parmPRVGKey = 0 THEN

					-- erase current settings
					UPDATE Privilege_Settings SET PRVS_FavoriteSeq = 0
        			WHERE PRVS_ID IN
        			(
        				SELECT	PRVS_ID
        				FROM	(	SELECT * FROM Privilege_Settings
        							INNER JOIN Users_Operators ON USRO_ID = PRVS_USRO_ID
        						) AS t1
        						WHERE	t1.USRO_USRM_ID	 =  parmUSRMKey
        						AND		t1.USRO_OPRS_ID	<=> parmOPRSKey
        			);

			END IF;

			-- parse the input data
			SET workSeq = parmSeqString;
			WHILE workSeq != '' DO
				BEGIN

					-- peel off a PRVN_ID and Seq #
					SET slice	= SUBSTRING_INDEX(workSeq, '|', 1);
					SET workSeq	= SUBSTRING(workSeq FROM LENGTH(slice)+2);
					SET prvn	= SUBSTRING_INDEX(slice, ',', 1);
					SET seq		= SUBSTRING(slice FROM LENGTH(prvn)+2);

					IF parmPRVGKey = 0 THEN	-- FAVORITES CATEGORY
						BEGIN

							UPDATE	Privilege_Settings
									INNER JOIN Users_Operators ON USRO_ID = PRVS_USRO_ID
									SET PRVS_FavoriteSeq	= seq,
                                	PRVS_UpdateUser			= (SELECT USRM_Name FROM Users_Main WHERE USRM_ID = parmUSRMKey),
                                	PRVS_UpdateUserIP1		= NULLIF(CONV(parmUpdateUserIP1,2,10),0),
                                	PRVS_UpdateUserIP2		= CONV(parmUpdateUserIP2,2,10),
									PRVS_UpdateTimestamp	= UTC_TIMESTAMP()
            				WHERE	PRVS_PRVN_ID	 =  prvn
            				AND		USRO_USRM_ID	 =  parmUSRMKey
            				AND		USRO_OPRS_ID	<=> parmOPRSKey;

						END;
					ELSE					-- "NORMAL" CATEGORY
						BEGIN

							UPDATE	Privilege_Settings
									INNER JOIN Users_Operators ON USRO_ID = PRVS_USRO_ID
									SET PRVS_CategorySeq	= seq,
                                	PRVS_UpdateUser			= (SELECT USRM_Name FROM Users_Main WHERE USRM_ID = parmUSRMKey),
                                	PRVS_UpdateUserIP1		= NULLIF(CONV(parmUpdateUserIP1,2,10),0),
                                	PRVS_UpdateUserIP2		= CONV(parmUpdateUserIP2,2,10),
									PRVS_UpdateTimestamp	= UTC_TIMESTAMP()
            				WHERE	PRVS_PRVN_ID	 =  prvn
            				AND		USRO_USRM_ID	 =  parmUSRMKey
            				AND		USRO_OPRS_ID	<=> parmOPRSKey;

						END;
					END IF;

				END;
			END WHILE;

		END;
	END IF;

END;