
DROP PROCEDURE IF EXISTS SYRF_Update;

CREATE PROCEDURE SYRF_Update
(
	IN parmID				smallint   UNSIGNED,
	IN parmType				smallint 	UNSIGNED,
	IN parmName				varchar(100),
	IN parmOldValueCount	tinyint		UNSIGNED,
	IN parmNewValueCount	tinyint		UNSIGNED,
	IN parmValueTypes		varchar(19),
	IN parmValueLabels		varchar(500),
	IN parmUpdateProgram	varchar(50),
	IN parmDeleteSQL		varchar(50),
	IN parmComments			varchar(500),
	IN parmUpdateUser		varchar(25),
	IN parmUpdateUserIP1	varchar(64),
	IN parmUpdateUserIP2	varchar(64)
)
BEGIN

	DECLARE itemID 		smallint 	UNSIGNED;
	DECLARE loopCount 		tinyint		UNSIGNED;
	DECLARE valueType		char(1);
	DECLARE valueData		varchar(100);

	# variables to read in each record from the cursor
	DECLARE val_SYRS_ID 			mediumint	UNSIGNED;
	DECLARE val_SYRV_ID 			mediumint	UNSIGNED;
	DECLARE val_SYRV_DataLabelID	tinyint		UNSIGNED;
	DECLARE val_SYRV_DataType		char(1);
	DECLARE val_SYRV_DataValue		varchar(100);

	# variables used just for cursor and loop control
	DECLARE no_more_rows			boolean;
	DECLARE num_rows 				int			UNSIGNED	DEFAULT 0;
	DECLARE break_on_SYRS			mediumint	UNSIGNED 	DEFAULT 0;
	DECLARE resetNeeded			boolean;
	DECLARE resetValue				varchar(100);

	DECLARE values_cursor CURSOR FOR
		SELECT SYRS_ID, SYRV_ID, SYRV_DataLabelID, SYRV_DataType, SYRV_DataValue
		FROM SysRefs_Values
		JOIN SysRefs_Sets 		ON SYRS_ID = SYRV_SYRS_ID
		JOIN SysRefs_Operators	ON SYRO_ID = SYRS_SYRO_ID
		JOIN SysRefs_Main		ON SYRF_ID = SYRO_SYRF_ID
		WHERE SYRF_ID = itemId;

	DECLARE CONTINUE HANDLER FOR NOT FOUND
		SET no_more_rows = TRUE;

	START TRANSACTION;

	# STEP 1: HANDLE THE SysRef_Groups INSTANCE (AND, IF INSERTING, THE SysRef_Operators INSTANCE)

	IF parmID = 0 THEN

		# insert new system references group
		DoInsert: BEGIN

			INSERT INTO SysRefs_Main
			(
				SYRF_Type,
				SYRF_Name,
				SYRF_ValueCount,
				SYRF_ValueTypes,
				SYRF_ValueLabels,
				SYRF_Comments,
				SYRF_UpdateProgram,
				SYRF_DeleteSQL,
				SYRF_UpdateUser,
				SYRF_UpdateUserIP1,
				SYRF_UpdateUserIP2,
				SYRF_UpdateTimestamp
			)
			VALUES
			(
				parmType,
				parmName,
				parmNewValueCount,
				parmValueTypes,
				parmValueLabels,
				parmComments,
				parmUpdateProgram,
				parmDeleteSQL,
				parmUpdateUser,
				NULLIF(CONV(parmUpdateUserIP1,2,10),0),
				CONV(parmUpdateUserIP2,2,10),
				UTC_TIMESTAMP()
			);

			SELECT LAST_INSERT_ID() INTO itemID;

			# make a place to which default values can be connected
			INSERT INTO SysRefs_Operators (SYRO_SYRF_ID, SYRO_OPRS_ID) VALUES (itemId, NULL);

			# insert a cross-reference for each active operator, too
			INSERT INTO SysRefs_Operators (SYRO_SYRF_ID, SYRO_OPRS_ID)
				SELECT itemId, OPRS_ID FROM Operators;

		END DoInsert;

	ELSE

		# update existing system references group
		DoUpdate: BEGIN

			UPDATE SysRefs_Main SET
				SYRF_Type			= parmType,
				SYRF_Name			= parmName,
				SYRF_ValueCount		= parmNewValueCount,
				SYRF_ValueTypes		= parmValueTypes,
				SYRF_ValueLabels	= parmValueLabels,
				SYRF_Comments		= parmComments,
				SYRF_UpdateProgram	= parmUpdateProgram,
				SYRF_DeleteSQL		= parmDeleteSQL,
				SYRF_UpdateUser		= parmUpdateUser,
				SYRF_UpdateUserIP1	= NULLIF(CONV(parmUpdateUserIP1,2,10),0),
				SYRF_UpdateUserIP2	= CONV(parmUpdateUserIP2,2,10),
				SYRF_UpdateTimestamp= UTC_TIMESTAMP()
			WHERE SYRF_ID			= parmID;

			SET itemId = parmID;

		END DoUpdate;

	END IF;

	# STEP 2: IF PREVIOUS # VALUE PROPERTIES != NEW # VALUE PROPERTIES, WE GOT SOME ADJUSTIN' TO DO
	# (if this was an insert, we've no work to be done, since there aren't any SYRS instances anyway)

	IF (parmID != 0) AND (parmOldValueCount != parmNewValueCount) THEN

		BEGIN

			# if there's been a decrease, delete all extraneous SYRV instances
			IF parmOldValueCount > parmNewValueCount THEN

				CREATE TEMPORARY TABLE SYRVKeys (delSYRVKey mediumint UNSIGNED);
				INSERT INTO SYRVKeys
					SELECT SYRV_ID
						FROM SysRefs_Values
						JOIN SysRefs_Sets 		ON SYRS_ID = SYRV_SYRS_ID
						JOIN SysRefs_Operators	ON SYRO_ID = SYRS_SYRO_ID
						JOIN SysRefs_Main		ON SYRF_ID = SYRO_SYRF_ID
					WHERE SYRF_ID = itemId AND SYRV_DataLabelID > parmNewValueCount;

				DELETE FROM SysRefs_Values
					WHERE SYRV_ID IN (SELECT * FROM SYRVKeys);

				DROP TABLE SYRVKeys;

			# if there's been an increase, add some new SYRV instances
			ELSE

				BEGIN
					SET loopCount = parmOldValueCount;
					insertSYRVLoop: LOOP

							SET loopCount = loopCount + 1;

							SET valueType  = SUBSTRING_INDEX(SUBSTRING_INDEX(parmValueTypes,  '|', loopCount), '|', -1);

							CASE valueType
								WHEN 'B' THEN 	SET valueData = '0';
								ELSE			SET valueData = '';
							END CASE;

							INSERT INTO SysRefs_Values (SYRV_SYRS_ID, SYRV_DataLabelID, SYRV_DataType, SYRV_DataValue)
								SELECT SYRS_ID, loopCount, valueType, valueData
								FROM SysRefs_Main
								JOIN SysRefs_Operators	ON SYRO_SYRF_ID = SYRF_ID
								JOIN SysRefs_Sets		ON SYRS_SYRO_ID = SYRO_ID
								WHERE SYRF_ID = itemId;

							IF loopCount = parmNewValueCount THEN
								LEAVE insertSYRVLoop;
							END IF;

					END LOOP insertSYRVLoop;
				END;

			END IF;

		END;

	END IF;

	# STEP #3: Inspect all Values for proper Type; if suspect, set to default

	OPEN values_cursor;
	SELECT FOUND_ROWS() into num_rows;

	vals_loop: LOOP

		FETCH values_cursor INTO val_SYRS_ID, val_SYRV_ID, val_SYRV_DataLabelID, val_SYRV_DataType, val_SYRV_DataValue;

		# break out of the loop if (1) there were no records, or (2) we've processed them all
		IF no_more_rows THEN
			CLOSE values_cursor;
			LEAVE vals_loop;
		END IF;

		SET resetNeeded = FALSE;

		SET valueType  = SUBSTRING_INDEX(SUBSTRING_INDEX(parmValueTypes, '|', val_SYRV_DataLabelID), '|', -1);
		IF (valueType != val_SYRV_DataType) THEN
			SET resetNeeded = TRUE;
		END IF;

		CASE valueType

			# Integer: if numeric, truncate to integer, else set to 0
			WHEN 'I' THEN
				BEGIN
					IF (TRIM(val_SYRV_DataValue) REGEXP '^(\-{0,1})([0-9]*)((\.{1})([0-9]*))$') THEN
						BEGIN
							SET resetValue = CONVERT(CONVERT(val_SYRV_DataValue, SIGNED INTEGER), CHAR);
							IF resetValue != val_SYRV_DataValue THEN
								SET resetNeeded = TRUE;
							END IF;
						END;
					ELSE
						BEGIN
							SET resetNeeded = TRUE;
							SET resetValue = '0';
						END;
					END IF;
				END;

			# Numeric: if not numeric, set to 0
			WHEN 'N' THEN
				BEGIN
					IF (TRIM(val_SYRV_DataValue) REGEXP '^(\-{0,1})([0-9]*)((\.{1})([0-9]*))$') THEN
						BEGIN
							SET resetValue = CONVERT(CONVERT(val_SYRV_DataValue, DECIMAL), CHAR);
							IF resetValue != val_SYRV_DataValue THEN
								SET resetNeeded = TRUE;
							END IF;
						END;
					ELSE
						BEGIN
							SET resetNeeded = TRUE;
							SET resetValue = '0';
						END;
					END IF;
				END;

			# String: no change should be needed
			WHEN 'S' THEN
				BEGIN
					SET resetValue = val_SYRV_DataValue;
				END;

			# Boolean: set to false unless existing value = 0, 1, or something other than FALSE (and, if so, it will be set to 1)
			WHEN 'B' THEN
				BEGIN
					IF (val_SYRV_DataValue != '0' AND val_SYRV_DataValue != '1') THEN
						BEGIN
							SET resetNeeded = TRUE;
							SET resetValue  = '0';
							IF UPPER(val_SYRV_DataValue) != "FALSE" THEN
								SET resetValue = '1';
							END IF;
						END;
					END IF;
				END;

			# Date: if current content is not a date (i.e., yyyy-mm-dd), replace with empty string
			WHEN 'D' THEN
				BEGIN
					IF (ISNULL(CONVERT(val_SYRV_DataValue, DATE))) THEN
						BEGIN
							SET resetNeeded = TRUE;
							SET resetValue  = '';
						END;
					ELSE
						IF (CONVERT(CONVERT(val_SYRV_DataValue, DATE), CHAR) != val_SYRV_DateValue) THEN
							BEGIN
								SET resetNeeded = TRUE;
								SET resetValue  = CONVERT(CONVERT(val_SYRV_DataValue, DATE), CHAR);
							END;
						END IF;
					END IF;
				END;

		END CASE;

		IF resetNeeded THEN
			BEGIN
				# update the value instance
				UPDATE SysRefs_Values SET SYRV_DataType = valueType, SYRV_DataValue = resetValue WHERE SYRV_ID = val_SYRV_ID;
				# if first of the set, also update the set instance
				IF val_SYRS_ID != break_on_SYRS	THEN
					BEGIN
						SET break_on_SYRS = val_SYRS_ID;
						UPDATE SysRefs_Sets SET
							SYRS_UpdateUser		= parmUpdateUser,
							SYRS_UpdateUserIP1	= NULLIF(CONV(parmUpdateUserIP1,2,10),0),
							SYRS_UpdateUserIP2	= CONV(parmUpdateUserIP2,2,10),
							SYRS_UpdateTimestamp= UTC_TIMESTAMP()
						WHERE SYRS_ID			= val_SYRS_ID;
					END;
				END IF;
			END;
		END IF;

	END LOOP vals_loop;


	# finally....
	COMMIT;

	# onward...
	SELECT itemId;

END;
