/*////////////////////////////////////////////////////////////////

When a new Operator is added, we need to create the default System
Reference values structure. This is done by basically replicating
the structure that's associated with the default "NULL" operator
tied to the "System Reference Values" instance of the SysRefs_Main
table.

1.	For each SysRefs_Main instance we need, for the new Operator,
	a SysRefs_Operators instance.

2.	Then, for each System_Operators instance, for each SysRefs_Main
	instance (excepting the "system Reference Values" instance!),
	we need the same SysRefs_Sets and SysRefs_Values instanaces

Sounds easy, but it's a but complicated, and practically speaking
cannot be accomplished apart from the use of cursors.

Author: 	Bob Carver
Created:	18 Jul 2010

////////////////////////////////////////////////////////////////*/

DROP PROCEDURE IF EXISTS SYRV_InitializeNewOperator;

CREATE PROCEDURE SYRV_InitializeNewOperator
(
	IN parmOPRSKey		mediumint,
	IN parmUsername		varchar(25),
	IN parmUserIP1		bigint,
	IN parmUserIP2		bigint
)
BEGIN

	# Variables to read in each record from the cursor
	DECLARE val_SYRF_ID 			smallint		UNSIGNED;
	DECLARE val_SYRF_Name 			varchar(100);
	DECLARE val_SYRS_ID			mediumint		UNSIGNED;
	DECLARE val_SYRS_IsRequired	boolean;
	DECLARE val_SYRS_Sequence		smallint		UNSIGNED;
	DECLARE val_SYRV_DataLabelID	tinyint			UNSIGNED;
	DECLARE val_SYRV_DataType		char(1);
	DECLARE val_SYRV_DataValue		varchar(100);

	# variables used just for cursor and loop control
	DECLARE no_more_rows			boolean;
	DECLARE num_rows 				int				UNSIGNED	DEFAULT 0;
	DECLARE break_on_SYRF			smallint 		UNSIGNED	DEFAULT 0;
	DECLARE break_on_SYRS			mediumint		UNSIGNED 	DEFAULT 0;
	DECLARE newSYROID				mediumint		UNSIGNED;
	DECLARE newSYRSID				mediumint		UNSIGNED;

	# and ... the cursor
	DECLARE values_cursor CURSOR FOR
		SELECT SYRF_ID, SYRF_Name, SYRS_ID, SYRS_IsRequired, SYRS_Sequence, SYRV_DataLabelId, SYRV_Datatype, SYRV_DataValue
		FROM SysRefs_Values
		JOIN SysRefs_Sets 		ON SYRS_ID = SYRV_SYRS_ID
		JOIN SysRefs_Operators 	ON SYRO_ID = SYRS_SYRO_ID AND SYRO_OPRS_ID IS NULL
		JOIN SysRefs_Main 		ON SYRF_ID = SYRO_SYRF_ID
		ORDER BY SYRF_ID, SYRS_ID, SYRS_Sequence, SYRV_DataLabelID;

	DECLARE CONTINUE HANDLER FOR NOT FOUND
		SET no_more_rows = TRUE;

	OPEN values_cursor;
	select FOUND_ROWS() into num_rows;

	vals_loop: LOOP

		FETCH values_cursor INTO val_SYRF_ID, val_SYRF_Name, val_SYRS_ID, val_SYRS_IsRequired, val_SYRS_Sequence, val_SYRV_DataLabelID, val_SYRV_DataType, val_SYRV_DataValue;

		# break out of the loop if (1) there were no records, or (2) we've processed them all
		IF no_more_rows THEN
			CLOSE values_cursor;
			LEAVE vals_loop;
		END IF;

		# do the hard work now
		START TRANSACTION;

		# 1. add the necessary SysRefs_Operators instance
		IF val_SYRF_ID != break_on_SYRF THEN
			SET break_on_SYRF = val_SYRF_ID;
			INSERT INTO SysRefs_Operators (SYRO_SYRF_ID, SYRO_OPRS_ID, SYRO_AuthorizedUsers)
				VALUES (val_SYRF_ID, parmOPRSKey, '');
			SELECT LAST_INSERT_ID() INTO newSYROID;
		END IF;

		#2. add the necessary SysRefs_Sets instance
		IF val_SYRS_ID != break_on_SYRS THEN
			SET break_on_SYRS = val_SYRS_ID;
			INSERT INTO SysRefs_Sets (SYRS_SYRO_ID, SYRS_IsRequired, SYRS_Sequence, SYRS_UpdateUser, SYRS_UpdateUserIP1, SYRS_UpdateUserIP2, SYRS_UpdateTimestamp)
				VALUES (newSYROID, val_SYRS_IsRequired, val_SYRS_Sequence, parmUsername, NULLIF(CONV(parmUserIP1,2,10),0), CONV(parmUserIP2,2,10), UTC_TIMESTAMP());
			SELECT LAST_INSERT_ID() INTO newSYRSID;
		END IF;

		#3. add the SysRefs_values instance
		INSERT INTO SysRefs_Values (SYRV_SYRS_ID, SYRV_DataLabelID, SYRV_DataType, SYRV_DataValue)
			VALUES (newSYRSID, val_SYRV_DataLabelID, val_SYRV_DataType, val_SYRV_DataValue);

		COMMIT;

	END LOOP vals_loop;

END;