/*////////////////////////////////////////////////////////////////

Change Active/Inactive State for System_Tables row

Author: 	Bob Carver
Created:	19 Jun 2010

////////////////////////////////////////////////////////////////*/

DROP PROCEDURE IF EXISTS TBLS_ChangeState;

CREATE PROCEDURE TBLS_ChangeState
(
	IN parmID				smallint	UNSIGNED,		# table item to be changed (TBLS_ID)
	IN parmNewStatus		tinyint,					# new status: 0 = active, 1 = inactive
	IN parmUSROKey			mediumint	UNSIGNED,		# the user (of operator) doing the change
	IN parmUpdateUserIP1	varchar(64),
	IN parmUpdateUserIP2	varchar(64),
	IN parmOptionalKey		int				# unused here!
)
BEGIN
	# Do the update first
		START TRANSACTION;
		UPDATE System_Tables SET
			TBLS_IsInactive		= parmNewStatus,
			TBLS_UpdateUser		= (SELECT USRM_Name FROM Users_Operators INNER JOIN Users_Main ON USRM_ID = USRO_USRM_ID = USRM_ID WHERE USRO_ID = parmUSROKey),
			TBLS_UpdateUserIP1	= NULLIF(CONV(parmUpdateUserIP1,2,10),0),
			TBLS_UpdateUserIP2	= CONV(parmUpdateUserIP2,2,10),
			TBLS_UpdateTimestamp= UTC_TIMESTAMP()
		WHERE TBLS_ID			= parmID;

		# Now log the action in the Audit Log
		# set Active...... type = 3 (parmNewStatus=0 + 3)
		# set Inactive ... type = 4 (parmNewStatus=1 + 3)

		CALL AUDT_Insert (parmNewStatus+3, (SELECT USRM_Name FROM Users_Operators INNER JOIN Users_Main ON USRM_ID = USRO_USRM_ID = USRM_ID WHERE USRO_ID = parmUSROKey), parmUpdateUserIP1, parmUpdateUserIP2, parmID, 'TBLS', NULL, NULL, NULL);
		COMMIT;
END;
