/*////////////////////////////////////////////////////////////////

Delete System_Tables row

Author: 	Bob Carver
Created:	24 Jun 2010

////////////////////////////////////////////////////////////////*/

DROP PROCEDURE IF EXISTS TBLS_Delete;

CREATE PROCEDURE TBLS_Delete
	(
		IN  parmID				smallint	UNSIGNED,
		IN  parmUSROID			mediumint	UNSIGNED,
		IN  parmUpdateUserIP1	varchar(64),
		IN  parmUpdateUserIP2	varchar(64)
	)
	BEGIN
		DECLARE tableName	varchar(50);
		DECLARE tableCode	char(4);
		DECLARE rowCount	int;
		DECLARE rowsFound	int;

		# If row isn't present we're done
		SELECT TBLS_TableName, TBLS_Code INTO tableName, tableCode FROM System_Tables WHERE TBLS_ID = parmID;
		SELECT FOUND_ROWS() INTO rowsFound;

		IF rowsFound = 0 THEN
			# the TBLS entry isn't around any longer
			BEGIN
				SELECT 0 AS ReturnCode, '' AS MoreInfo;
			END;
		ELSE
			BEGIN

                # Does table have any rows?
                SELECT information_schema.TABLES.TABLE_ROWS INTO rowCount FROM information_schema.TABLES
                WHERE information_schema.TABLES.TABLE_SCHEMA = 'MAESS'
                AND   LOWER(information_schema.TABLES.TABLE_NAME) = LOWER(tableName);
                SELECT FOUND_ROWS() INTO rowsFound;

                # if it's in the schema (rowsFound > 0) and there are rows in the table (rowCount > 0), reject the delete
				IF rowsFound > 0 AND rowCount > 0 THEN
                	BEGIN
                		SELECT 1 AS ReturnCode, CONCAT(FORMAT(rowCount,0), ' rows present') AS MoreInfo;
                	END;
                ELSE
                	# it's not even in the schema or it is but the table is empty, do the delete
                	BEGIN
						START TRANSACTION;
                		DELETE FROM System_Tables WHERE TBLS_ID = parmID;
                		CALL AUDT_Insert (2, (SELECT USRM_Name FROM Users_Operators INNER JOIN Users_Main ON USRM_ID = USRO_USRM_ID = USRM_ID WHERE USRO_ID = parmUSROID), parmUpdateUserIP1, parmUpdateUserIP2, parmID, 'TBLS', NULL, NULL, CONCAT(tableName, ' (', tableCode, ')'));
                		COMMIT;
						SELECT 0 AS ReturnCode, '' AS MoreInfo;
                	END;
                END IF;
			END;
		END IF;

	END;
