/*////////////////////////////////////////////////////////////////

Change Active/Inactive State for Users_Main row

Author: 	Bob Carver
Created:	10 Jul 2010
Modified:	12 Jul 2010	-	Handle move of IsInactive and InactiveTimestamp
							to Users_Operators table

////////////////////////////////////////////////////////////////*/

DROP PROCEDURE IF EXISTS USRM_ChangeState;

CREATE PROCEDURE USRM_ChangeState
(
	IN parmID				smallint	UNSIGNED,		# user to be changed (USRM_ID)
	IN parmNewStatus		tinyint,					# new status: 0 = active, 1 = inactive
	IN parmUSROKey			mediumint	UNSIGNED,		# the user (of operator) doing the change
	IN parmUpdateUserIP1	varchar(64),
	IN parmUpdateUserIP2	varchar(64),
	IN parmOptionalKey		int			UNSIGNED		# the user (or operator) being changed
)
BEGIN

	DECLARE inactiveTS 	timestamp DEFAULT NULL;
	DECLARE reqUser		varchar(25);
	DECLARE reqIsSuperUser	boolean;

	IF parmNewStatus = 1 THEN SET inactiveTS = UTC_TIMESTAMP(); END IF;

	# get some info re: requesting user
	SELECT USRM_Name, USRM_IsSuperUser INTO reqUser, reqIsSuperUser FROM Users_Operators INNER JOIN Users_Main ON USRM_ID = USRO_USRM_ID WHERE USRO_ID = parmUSROKey;

	START TRANSACTION;

		# Do the main update first
		UPDATE Users_Main SET
			USRM_UpdateUser			= reqUser,
			USRM_UpdateUserIP1		= NULLIF(CONV(parmUpdateUserIP1,2,10),0),
			USRM_UpdateUserIP2		= CONV(parmUpdateUserIP2,2,10),
			USRM_UpdateTimestamp	= UTC_TIMESTAMP()
		WHERE	USRM_ID				= parmID;

		# No change the appropriate Users_Operators instance
		UPDATE Users_Operators SET
			USRO_IsInactive			= parmNewStatus,
			USRO_InactiveTimestamp	= inactiveTS
		WHERE	USRO_ID	= parmOptionalKey;

		# Now log the action in the Audit Log
		# set Active...... type = 3 (parmNewStatus=0 + 3)
		# set Inactive ... type = 4 (parmNewStatus=1 + 3)

		CALL AUDT_Insert (parmNewStatus+3, reqUser, parmUpdateUserIP1, parmUpdateUserIP2, parmID, 'USRM', parmOptionalKey, 'USRO', NULL);

	COMMIT;

END;
